*** eta-ind.do
local v = "2.4"
*** 29 May 2010
***
*** "Industry Effects of Government Spending"
*** Chris Nekarda and Valerie Ramey
***
*** Description:  Estimates dv/dh in 2-digit industry data using Bils's (1987) specification
***
*** Requires:
***     eedata-sic2-q-sa.dta (CES 2-digit SIC industry data)
***
***************************************************************************************************
clear
set more off
capture log close
log using eta-ind-q.log, replace

use eedata-sic2-q-sa.dta, replace

gen dv = D.v
gen dh = D.h

gen lh = L.h-40
gen lh2 = lh^2
gen lh3 = lh^3
gen dhlh = dh*lh
gen dhlh2 = dh*lh2
gen dhlh3 = dh*lh3

gen t = (qdate + 16)/100
gen t2 = t^2
gen t3 = t^3

gen dht = dh*t
gen dht2 = dh*t2
gen dht3 = dh*t3

gen dln = ln(N/L.N)
gen d2ln = dln - L.dln

** Bils (1987) specification (full cubics and industry dummies)
xi i.sic2 i.sic2*dh i.sic2*dht i.sic2*dln i.sic2*d2ln
#delim ;
noi reg dv _Isic2_?? dh _IsicXdh_* dht _IsicXdht_* dht2 dht3 dhlh dhlh2 dhlh3
    dln _IsicXdln_* d2ln _IsicXd2ln_* t t2 t3;

gen eta = 0
    /* b_{i0} */
    + _b[dh]                    + _b[_IsicXdh_21]*_Isic2_21
    + _b[_IsicXdh_22]*_Isic2_22 + _b[_IsicXdh_23]*_Isic2_23
    + _b[_IsicXdh_24]*_Isic2_24 + _b[_IsicXdh_25]*_Isic2_25
    + _b[_IsicXdh_26]*_Isic2_26 + _b[_IsicXdh_27]*_Isic2_27
    + _b[_IsicXdh_28]*_Isic2_28 + _b[_IsicXdh_29]*_Isic2_29
    + _b[_IsicXdh_30]*_Isic2_30 + _b[_IsicXdh_31]*_Isic2_31
    + _b[_IsicXdh_32]*_Isic2_32 + _b[_IsicXdh_33]*_Isic2_33
    + _b[_IsicXdh_34]*_Isic2_34 + _b[_IsicXdh_35]*_Isic2_35
    + _b[_IsicXdh_36]*_Isic2_36 + _b[_IsicXdh_37]*_Isic2_37
    + _b[_IsicXdh_38]*_Isic2_38 + _b[_IsicXdh_39]*_Isic2_39
    /* b_{i1} */
    + _b[dht]*t                    + _b[_IsicXdht_21]*_Isic2_21*t
    + _b[_IsicXdht_22]*_Isic2_22*t + _b[_IsicXdht_23]*_Isic2_23*t
    + _b[_IsicXdht_24]*_Isic2_24*t + _b[_IsicXdht_25]*_Isic2_25*t
    + _b[_IsicXdht_26]*_Isic2_26*t + _b[_IsicXdht_27]*_Isic2_27*t
    + _b[_IsicXdht_28]*_Isic2_28*t + _b[_IsicXdht_29]*_Isic2_29*t
    + _b[_IsicXdht_30]*_Isic2_30*t + _b[_IsicXdht_31]*_Isic2_31*t
    + _b[_IsicXdht_32]*_Isic2_32*t + _b[_IsicXdht_33]*_Isic2_33*t
    + _b[_IsicXdht_34]*_Isic2_34*t + _b[_IsicXdht_35]*_Isic2_35*t
    + _b[_IsicXdht_36]*_Isic2_36*t + _b[_IsicXdht_37]*_Isic2_37*t
    + _b[_IsicXdht_38]*_Isic2_38*t + _b[_IsicXdht_39]*_Isic2_39*t
      /* b_2 */     /*b_3 */
    + _b[dht2]*t2 + _b[dht3]*t3
      /* c_1 */     /* c_2 */       /* c_3 */
    + _b[dhlh]*lh + _b[dhlh2]*lh2 + _b[dhlh3]*lh3
    ;
#delim cr

noi tabstat eta, by(sic2) s(mean sd min max) for(%04.3f)

* collapse to annual frequency
keep sic2 qdate eta
keep if qdate>=tq(1958q1) & qdate<=tq(2002q4)
gen int year=year(dofq(qdate))
collapse (mean) eta, by(sic2 year)
label var eta ""
sort sic2 year
compress
save eta-ind.dta, replace

capture log close
